#
# spec file for package python-blosc
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-blosc
Version:        1.5.1
Release:        bp153.1.14
Summary:        Blosc data compressor for Python
License:        MIT
Group:          Development/Languages/Python
Url:            http://www.blosc.org/
Source:         https://files.pythonhosted.org/packages/source/b/blosc/blosc-%{version}.tar.gz
BuildRequires:  blosc-devel
BuildRequires:  gcc-c++
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module numpy-devel}
Requires:       blosc-devel
Requires:       python-numpy
ExclusiveArch:  %ix86 x86_64
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%python_subpackages

%description
Blosc is a high performance compressor optimized for binary data in
Python.

%prep
%setup -q -n blosc-%{version}

%build
export CFLAGS="%{optflags}"
%python_exec setup.py build_ext --inplace --blosc=%{_prefix}

%install
%python_exec setup.py install -O1 --skip-build --force --root=%{buildroot} --prefix=%{_prefix} --blosc=%{_prefix}
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%files %{python_files}
%defattr(-,root,root,-)
%doc ANNOUNCE.rst README.rst LICENSES/*.txt RELEASE_NOTES.rst
%{python_sitearch}/blosc-%{version}-py*.egg-info
%{python_sitearch}/blosc/

%changelog
* Sun Jan 21 2018 toddrme2178@gmail.com
- Fix building
* Wed Apr 19 2017 toddrme2178@gmail.com
- Source url must be https.
* Wed Apr 19 2017 toddrme2178@gmail.com
- Update to version 1.5.1
  * License updated from MIT to BSD.
  * Updated to C-Blosc 1.11.3.
- Update to version 1.5.0
  * Added a new `blosc.set_releasegil()` function that allows to
    release/acquire the GIL at will.  See PR #116.
    Thanks to Robert McLeod.
  * Updated to C-Blosc 1.11.2.
  * Added tests that detect possible memory leaks.
    Thanks to Robert McLeod.
- Update to version 1.4.4
  * Updated to C-Blosc 1.11.1.  Fixes #115.
- Update to version 1.4.3
  * Internal C-Blosc sources updated to 1.11.0. Among other things, this
    updates the internal Zstd codec to version 1.0.0 (i.e. it is
    officially apt for production usage!).
- Update to version 1.4.1
  * Internal C-Blosc sources updated to 1.10.1.  This fixes an outstanding issue
    with the clang compiler.  For details, see:
    https://github.com/Blosc/bloscpack/issues/50.
- Update to version 1.4.0
  * Internal C-Blosc sources updated to 1.10.0.
  * Benchmarks updated for a Skylake processor (Xeon E3-1245 v5 @
    3.50GHz).
- Update to version 1.3.3
  * Internal C-Blosc sources updated to 1.9.3.
  * C-Blosc do not segfaults anymore, so -O1 flag on Linux is not the
    default anymore.
  * SSE2 and AVX2 are now auto-discovered so the internal C-Blosc will be
    compiled with maximum optimization on processors supporting them.
- Update to version 1.3.2
  * Fixed the version of the include C-Blosc library (should be 1.8.1 not
    1.8.2.dev).
- Update to version 1.3.1
  * Use the -O1 flag for compiling the included C-Blosc sources on Linux.
    This represents slower performance, but fixes the nasty issue #110.
    Also, it prints a warning for using an external C-Blosc library.
  * Internal C-Blosc version bumped to 1.8.1 for better compatibility
    with gcc 5.3.1 in forthcoming Ubuntu Xenial.
  * Added a protection to avoid using BITSHUFLE with C-Blosc < 1.8.0.
  * Restored old symbols for backward compatibility with pre 1.3.0:
    BLOSC_VERSION_STRING
    BLOSC_VERSION_DATE
    BLOSC_MAX_BUFFERSIZE
    BLOSC_MAX_THREADS
    BLOSC_MAX_TYPESIZE
    However, these are considered deprecated and should be replaced by
    libraries using python-blosc by the ones without the BLOSC_ prefix.
- Update to version 1.3.0
  * Internal C-Blosc version bumped to 1.8.0.  As consequence, support for
    BITSHUFFLE is here.  For activating it, just pass `blosc.BITSHUFFLE`
    to the `shuffle` parameter of compression functions.
  * Added a new `as_bytearray=False` parameter to the `decompress()` function
    so that a mutable bytearray will be returned instead of a bytes one
    (inmutable).  PR #107.  Thanks to Joe Jevnik.
  * The '__all__' variable has been removed from the module.  I consider
    this good practice to avoid things like "from blosc import *".
  * For consistency, the next symbols have been renamed:
    BLOSC_VERSION_STRING -> VERSION_STRING,
    BLOSC_VERSION_DATE -> VERSION_DATE,
    BLOSC_MAX_BUFFERSIZE -> MAX_BUFFERSIZE,
    BLOSC_MAX_THREADS -> MAX_THREADS,
    BLOSC_MAX_TYPESIZE -> MAX_TYPESIZE,
  * The `typesize` parameter is set by default to 8 in compression
    functions.  This usually behaves well for 4-bytes typesizes too.
    Nevertheless, it is advised to use the actual typesize.
  * The maximum number of threads to use by default is set to 4 (less if
    less cores are detected).  Feel free to use more or less threads
    depending on the resources you want to use for compression.
- Implement single-spec version.
* Thu Mar 10 2016 toddrme2178@gmail.com
- Update to version 1.2.8
  * Updated to c-blosc v1.7.0. However, the new bitshuffle filter
    has not been made public because recent reports indicate that
    it seems too green for production.
  * Support bytes-like objects that support the buffer interface
    as input to compress and decompress. On Python 2.x this
    includes unicode, on Python 3.x it doesn't. (#80 #94 @esc)
  * Fix a memory leak in decompress. Added tests to catch memory
    leaks. (#102 #103 #104 @sdvillal)
  * Various miscellaneous fixes and improvements.
* Tue May 19 2015 toddrme2178@gmail.com
- Update to version 1.2.7
  * Updated to c-blosc v1.6.1.
* Sun Apr 26 2015 benoit.monin@gmx.fr
- update to version 1.2.5:
  * Updated to c-blosc v1.5.4.
  * Added wrapper for the expert function ``set_blocksize``.
    (#72 @esc)
  * Fix setup.py to allow compilation on posix architectures
    without SSE2. (#70 @andreas-schwab)
  * Don't release the GIL on compression/decompression (#77 @esc)
  * Various miscellaneous fixes.
- drop setup.patch: fixed upstream
* Wed Aug  6 2014 schwab@suse.de
- setup.patch: fix use of unknown compiler option
* Thu Jul 17 2014 toddrme2178@gmail.com
- Update to 1.2.4
  - Updated to c-blosc 1.4.0.  This added support for non-Intel
    architectures, most specially those not supporting unaligned access.
* Thu May  8 2014 toddrme2178@gmail.com
- Update to 1.2.3
  - Updated to c-blosc 1.3.5.  This removed a 'pointer from integer
    without a cast' compiler warning due to a bad macro definition.
- Update to 1.2.2
  - Updated to c-blosc 1.3.4.  This fixed a false buffer overrun
    condition.  This bug made c-blosc (and hence python-blosc) to fail,
    even if the failure was not real.
- Update to 1.2.1
  - Updated to c-blosc 1.3.3.
  - Added a new `cname2clib` map for programatically determine the library
    associated to a compressor.
  - New `get_clib(cbuffer)` that tells which compression library format
    has been used to created the compressed `cbuffer`.
- Update to 1.2.0
  - This release adds support for the multiple compressors added in Blosc
    1.3 series.
  - Added new `cname` parameter in compression functions like
    `compress()`, `compress_ptr()` and `pack_array()`.
  - Added a new utility function named `compressor_list()` that returns
    the list of compressors supported in the Blosc build.
  - Added 'bench/compress_ptr.py' for comparing times of the different
    compressors in Blosc and NumPy.
- Update to 1.1.0
  - Added new `compress_ptr` and `decompress_ptr` functions that allows to
    compress and decompress from/to a data pointer.  These are low level
    calls and user must make sure that the pointer data area is safe.
  - Since Blosc (the C library) already supports to be installed as an
    standalone library (via cmake), it is also possible to link
    python-blosc against a system Blosc library.
  - The Python calls to Blosc are now thread-safe (another consequence of
    recent Blosc library supporting this at C level).
  - Many checks on types and ranges of values have been added.  Most of
    the calls will now complain when passed the wrong values.
  - Docstrings are much improved. Also, Sphinx-based docs are available
    now.
- Update to 1.0.6
  - Fix compile error with msvc compilers.  Thanks to Christoph Gohlke.
- Update to 1.0.5
  - Upgraded to latest Blosc 1.1.4.
  - Better handling of condition errors, and improved memory releasing in
    case of errors (thanks to Valentin Haenel and Han Genuit).
  - Better handling of types (should compile without warning now, at least
    with GCC).
- Update to 1.0.4
  - Optimized the amount of data copied during compression (using
    _PyBytes_Resize() now instead of old PyBytes_FromStringAndSize()).
    This leads to improvements in compression speed ranging from 1.2x for
    highly compressible chunks up to 7x for mostly uncompressible data.
    Thanks to Valentin Haenel for this nice contribution.
- Use external blosc library.  The internal one builds a bad version
  of zlib.
* Fri Sep  7 2012 toddrme2178@gmail.com
- Initial version
